<?php
if(!defined('ABSPATH'))die; // disable direct accessed

if (!defined('WPSLS_PLUGIN_NAME')) {
    define('WPSLS_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));
}
if (!defined('WPSLS_PLUGIN_URL')) {
    define('WPSLS_PLUGIN_URL', WP_PLUGIN_URL . '/' . WPSLS_PLUGIN_NAME);
}


function WP_sls_init(){ 
	// make the plugin i18n and l10n ready
	load_plugin_textdomain('WP-simple-login-security', false, dirname(plugin_basename(__FILE__)) . '/languages');
}


// execute when the plugin is activated
function WP_sls_activation() { 
	global $WP_sls_options;

	/* DEFAULT
	 * let's set the default value for important variables
	 * this value can be modified by administrator
	 */
	$WP_sls_options['alt_wplogin_name'] = '';
	$WP_sls_options['safe_redirect_location'] = 'http://127.0.0.1/';
	$WP_sls_options['enable_dual_authentication'] = 'yes';
	$WP_sls_options['disable_remember_me'] = 'yes';
	$WP_sls_options['enable_logging'] = 'no';
	$WP_sls_options['enable_obscure_error_messages'] = 'yes';
	$WP_sls_options['show_powered_by'] = 'no';
	$WP_sls_options['max_allowable_login_attempt'] = '10';
	$WP_sls_options['first_installed'] = 'yes';  // we will use this to show the welcome message
	
	add_option('WP_sls_options',$WP_sls_options);

	/*
	 * let's install custom table
	 */
	WP_sls_update_db_check();
}



// execute when the plugin is deactivated
function WP_sls_deactivation() { 
	// do nothing here
	// user may activate the plugin again
	
	// removal of database tables and deletion of options
	// takes place in user delete the plugin
	// see uninstall.php
}




// install the database table
function WP_sls_dbtable_install() {

	global $wpdb;
	global $WP_sls_dbtable_version;
	
	$access_log_table = $wpdb->prefix . "WP_sls_accesslog";
	$session_log_table = $wpdb->prefix . "WP_sls_sessionlog";
	$sql_sessionlog = "CREATE TABLE ".$session_log_table." (
	userid varchar(30) NOT NULL,
	authcode varchar(100) NOT NULL,
	UNIQUE KEY (userid),
	INDEX (authcode)
	)ENGINE=MyISAM DEFAULT CHARSET=utf8;";   

	$sql_accesslog = "CREATE TABLE ".$access_log_table." (
	accid bigint(20) NOT NULL AUTO_INCREMENT,
	username varchar(50) NOT NULL,
	log_time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
	authcode varchar(100) DEFAULT '' NOT NULL,
	log_status varchar(100) DEFAULT '' NOT NULL,
	IP varchar(100) DEFAULT '' NOT NULL,
	UNIQUE KEY (accid),
	INDEX (username),
	INDEX (log_time),
	INDEX (authcode),
	INDEX (log_status),
	INDEX (IP)
	)ENGINE=MyISAM DEFAULT CHARSET=utf8;";

	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql_sessionlog );
	dbDelta( $sql_accesslog );

	update_option( "WP_sls_dbtable_version", $WP_sls_dbtable_version ); 
}

// update the table when plugin is updated with higher table version

function WP_sls_update_db_check() {

    global $WP_sls_dbtable_version;
	/*
	 * if the table version installed is less than the latest version,
	 * let's install the newest table version
	 */
    if (get_option( 'WP_sls_dbtable_version' ) == $WP_sls_dbtable_version) {
		// the table version is the same so no need to update
	} else {
		/* there's a new version of table
		 * let's update the table */
        WP_sls_dbtable_install();
    }
}




/**
 * Taken from: https://gist.github.com/cballou/2201933
 * Retrieves the best guess of the client's actual IP address.
 * Takes into account numerous HTTP proxy headers due to variations
 * in how different ISPs handle IP addresses in headers between hops.
 * 
 * Modified by Jesse Veluz:
 * I added the word "via" to keep the REMOTE_ADDR since REMOTE_ADDR is the most reliable IP
 * Ex:
 *    xxx.xxx.xxx.xxx via xxx.xxx.xxx.xxx
 *
 */
function WP_sls_get_ip_address() {

	// check for shared internet/ISP IP
	if (!empty($_SERVER['HTTP_CLIENT_IP']) && WP_sls_validate_ip($_SERVER['HTTP_CLIENT_IP'])) {
		return $_SERVER['REMOTE_ADDR'] .' via '. $_SERVER['HTTP_CLIENT_IP'];
	}

	// check for IPs passing through proxies
	if (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
		// check if multiple ips exist in var
		if (strpos($_SERVER['HTTP_X_FORWARDED_FOR'], ',') !== false) {
			$iplist = explode(',', $_SERVER['HTTP_X_FORWARDED_FOR']);
			foreach ($iplist as $ip) {
				if (WP_sls_validate_ip($ip)) {
					return $_SERVER['REMOTE_ADDR'] .' via '. $ip;
				}
			}
		} else {
			if (WP_sls_validate_ip($_SERVER['HTTP_X_FORWARDED_FOR'])) {
				return $_SERVER['REMOTE_ADDR'] .' via '. $_SERVER['HTTP_X_FORWARDED_FOR'];
			}
		}
	}

	if (!empty($_SERVER['HTTP_X_FORWARDED']) && WP_sls_validate_ip($_SERVER['HTTP_X_FORWARDED']))
		return $_SERVER['REMOTE_ADDR'] .' via '. $_SERVER['HTTP_X_FORWARDED'];
	if (!empty($_SERVER['HTTP_X_CLUSTER_CLIENT_IP']) && WP_sls_validate_ip($_SERVER['HTTP_X_CLUSTER_CLIENT_IP']))
		return $_SERVER['REMOTE_ADDR'] .' via '. $_SERVER['HTTP_X_CLUSTER_CLIENT_IP'];
	if (!empty($_SERVER['HTTP_FORWARDED_FOR']) && WP_sls_validate_ip($_SERVER['HTTP_FORWARDED_FOR']))
		return $_SERVER['REMOTE_ADDR'] .' via '. $_SERVER['HTTP_FORWARDED_FOR'];
	if (!empty($_SERVER['HTTP_FORWARDED']) && WP_sls_validate_ip($_SERVER['HTTP_FORWARDED']))
		return $_SERVER['REMOTE_ADDR'] .' via '. $_SERVER['HTTP_FORWARDED'];

	// return REMOTE_ADDR since all else failed
	return $_SERVER['REMOTE_ADDR'];
}



// if plugin is used and activated for the first time
// show message to set the security
function WP_sls_admin_notices() {
	global $WP_sls_options;
	// when a plugin is first installed, security is enabled by default
	// if $WP_sls_options['alt_wplogin_name'] is empty and security is enabled, then this plugin is freshly installed
	// so let's show some message
	if ( $WP_sls_options['first_installed']=='yes' ){
		if (isset($_GET['page']) && strpos($_SERVER['REQUEST_URI'],'WP_sls')){
		} else {			
			if (get_option( 'users_can_register' )){
				echo '<div class="error">';
				echo '<h3>'.__('Congratulations, WP Simple Login Security has been installed!', 'WP-simple-login-security').'</h3>';
				$url = get_admin_url().'admin.php?page=WP_sls';
				echo '<p style="color: red; font-size: 14px; font-weight: bold;clear:both;">'.sprintf(__('Please don\'t forget to to visit the <a href="%s">settings page</a> to secure the login page.', 'WP-simple-login-security'), esc_url( $url )).'</p></div>';
			} else {
				echo '<div class="error">';
				echo '<h3>'.__('Congratulations, WP Simple Login Security has been installed!', 'WP-simple-login-security').'</h3>';
				$url = get_admin_url().'admin.php?page=WP_sls';
				echo '<p style="color: red; font-size: 14px; font-weight: bold;clear:both;">'.sprintf(__('Your login URL is not secured.  Please go to <a href="%s">settings page</a> now to protect it.', 'WP-simple-login-security'), esc_url( $url )).'</p></div>';
			}
		}
	}
}



// redirect to page
function WP_sls_redirectto( $WP_sls_url ){ 
	if (!headers_sent()){
		header('Location: '.$WP_sls_url);
		exit;
	} else {
		echo '<meta http-equiv="refresh" content="0;url='.$WP_sls_url.'" />';
	}
}


/**
 * Redirect user after successful login.
 *
 * @param string $redirect_to URL to redirect to.
 * @param string $request URL the user is coming from.
 * @param object $user Logged user's data.
 * @return string
 */
function WP_sls_login_redirect( $redirect_to, $request, $user ) {

	global $WP_sls_options;
	global $WP_sls_user_ip;
	global $wpdb;

	//is there a user to check?
	global $user;

	if ( isset( $user->roles ) && is_array( $user->roles ) ) {

		if ($WP_sls_options['enable_logging']=='yes'){
			
			if ($WP_sls_options['enable_dual_authentication']=='yes'){
				$WP_sls_results = $wpdb->get_results("SELECT authcode FROM ".$wpdb->prefix."WP_sls_sessionlog WHERE userid='".$user->data->user_login."'");
				
				if ($wpdb->num_rows){					
					/*
					 * update the log with authcode
					 */				
					$wpdb->insert($wpdb->prefix."WP_sls_accesslog",
						array( 
							'username'=>$user->data->user_login,
							'log_time'=>date('Y-m-d H:i:s'),
							'authcode'=>$WP_sls_results[0]->authcode,
							'log_status' => 'logged',
							'IP' => $WP_sls_user_ip
						),
						array( 
							'%s','%s','%s','%s','%s'
						)
					);
				} 
			} else { 
				// dual factor authentication is not enabled so we logged without authcode
				$wpdb->insert($wpdb->prefix."WP_sls_accesslog",
					array( 
						'username'=>$user->data->user_login,
						'log_time'=>date('Y-m-d H:i:s'),
						'authcode'=>__('dual-factor authentication is disabled','WP-simple-login-security'),
						'log_status' => 'logged',
						'IP' => $WP_sls_user_ip
					),
					array( 
						'%s','%s','%s','%s','%s'
					)
				);
			}
		}		
	}
	return $redirect_to;
}

/*
 * let's process some stuffs before the login form shows up
 */
function WP_sls_login_head(){ 
	global $user;
	global $WP_sls_options;
	
	if (!isset($_POST['WP_sls_security_try'])){
		$_POST['WP_sls_security_try'] = 0;
	} else { 
		$_POST['WP_sls_security_try']++;
	}
	
	$warning_try = $WP_sls_options['max_allowable_login_attempt']-2;
	if ($_POST['WP_sls_security_try']==$warning_try){
		$user->error_data['WP_sls_warning'] = sprintf( __( 'You have failed for %d times already, 2 more failed attempts and this login page will be locked down.','WP-simple-login-security' ), $warning_try );
	}
	
	if ($_POST['WP_sls_security_try']>=$WP_sls_options['max_allowable_login_attempt']){
		WP_sls_redirectto($WP_sls_options['safe_redirect_location']);
	}
	
	if (@count($user->errors)){
		
		if (isset($_POST['WP_sls_security_code'])){
			$user->error_data['attemptcode'] = 2;
			$user->error_data['logstr'] = $_POST['log'];
		}
		
		if (isset($user->errors['WP_sls_incorrect_code'])){
			log_incorrect_code($user->error_data['logstr']);
		}
		
		if (isset($user->errors['empty_password']) || isset($user->errors['incorrect_password']) ){
			log_wrong_password($_POST['log']);
		}
		
			
		if (isset($user->error_data['attemptcode']) && $user->error_data['attemptcode']==1){
			/*
			 * let's send the second password to user's email
			 */
			WP_sls_send_code_by_email($user->error_data['logstr'],$user->error_data['usreml']);
		} else {
			if ($WP_sls_options['enable_obscure_error_messages']=='yes'){
				add_filter('login_errors','WP_sls_login_errors');
			}
		}
	} 
}


/*
 * create session authcode on the sessionlog table
 */
function WP_sls_create_session($user_login){ 

	global $wpdb;
	global $WP_sls_options;

	if ($WP_sls_options['enable_dual_authentication']=='yes'){
		$WP_sls_init_code = str_shuffle('aabbccddeeffgghhiijjkkllmmnnnooopppqqqrrrssstttuuvvvwxxwwyzz11223344556677889900');
		$WP_sls_security_code = substr($WP_sls_init_code, -5);
	} else { 
		$WP_sls_security_code = __('dual-factor authentication disabled','WP-simple-login-security');
	}
	
	// check if user exists in the session
	$query = "SELECT userid FROM ".$wpdb->prefix."WP_sls_sessionlog where userid='".$user_login."'";
	$resultcount = $wpdb->query($query);
	
	if ($resultcount>0){
		// then let's update with new code
		$wpdb->update( $wpdb->prefix.'WP_sls_sessionlog', 
			array( 'authcode'=>$WP_sls_security_code ), 
			array( 'userid' => $user_login ), 
			array( '%s' ), 
			array( '%s' ) 
		);
	} else { 
		// let's insert
		$wpdb->insert($wpdb->prefix."WP_sls_sessionlog",
			array(
				'userid'=>$user_login,
				'authcode'=>$WP_sls_security_code
			),
			array( 
				'%s',
				'%s'
			)
		);
	}
	
	return $WP_sls_security_code;
}



/*
 * send the second password by email
 */
function WP_sls_send_code_by_email($user_login,$user_email){ 
	
	$WP_sls_security_code = WP_sls_create_session($user_login);
											
	/*
	 * let's send the second code to user's email
	 */			
	$the_message = sprintf(__("
Dear %s,

Thank you for using WP Simple Login Security.

Here is your Authentication Code for this current session: %s

Please ensure you check your Usage Log to see if any unauthorised attempts to login have been made. 

If there have been, then we recommend you change your Login Key within the Login Settings page so that 
unauthorized visitors cannot return to the same login page again.  Changing your Login Key on a regular
basis is recommended. 

WP Simple Login Security Team
","WP-simple-login-security"),$user_login,$WP_sls_security_code); 
	 
	$WP_sls_authentication_message = $the_message;

	$WP_sls_authentication_title = '[WP Simple Login Security] '.__('Your authentication code','WP-simple-login-security');

	if ( !wp_mail( $user_email, $WP_sls_authentication_title, $WP_sls_authentication_message) ) {

		wp_die( __('The e-mail could not be sent.','WP-simple-login-security') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function.','WP-simple-login-security') );

	}
}



/*
 * to obscure the login error messages
 */
function WP_sls_login_errors(){ 
	return '<strong>'.__('ERROR:','WP-simple-login-security').'</strong> '.__('Incorrect login details','WP-simple-login-security');
}



/*
 * let's define the constant to prevent caching
 * or redirect user if it doesn't know the login key
 */
function WP_sls_login_init() { 
	
	global $WP_sls_options;
	
	if ( !defined('DONOTCACHEPAGE') ){
		define('DONOTCACHEPAGE',true);
	}
	
	if ($WP_sls_options['alt_wplogin_name']==''){
		/* login key is not required
		 * so let's just proceed with the login form */
	} else { 
		if ( stripos($_SERVER['REQUEST_URI'],$WP_sls_options['alt_wplogin_name']) ){
			/* login key is present so let's
			 * allow the user to proceed */
		} else { 
			/* LOGIN KEY is not present
			 * 
			 * let's have another test */
			 if ($_SERVER["QUERY_STRING"]!=''){
				 /* allow 
				  * registration
				  * lost password
				  * reset password
				  * and other wp-login page except the login form
				  */
				  if (isset($_SERVER["HTTP_REFERER"])){
					  if ( stripos($_SERVER["HTTP_REFERER"],$WP_sls_options['alt_wplogin_name']) ){
					  	// just proceed
					  } else { 
					  /*
						* not a valid access
						* ex: blog_url/wp-login.php?action=lostpassword (the referrer does not contain the login key) */
						WP_sls_redirectto($WP_sls_options['safe_redirect_location']);
					  }
				  } else { 
					if ( stripos($_SERVER["REQUEST_URI"],'action=rp') ){
						// let's allow reset password form
					} else {
						/*
						* not a valid access
						* ex: blog_url/wp-login.php?action=lostpassword (direct input)
						* ex: blog_url/wp-login.php?whatever (direct input) */
						WP_sls_redirectto($WP_sls_options['safe_redirect_location']);
					}
				  }
			 } else {
				 /*
				  * not a valid access
				  * ex: blog_url/wp-login.php
				  * this should be redirected somewhere */
				WP_sls_redirectto($WP_sls_options['safe_redirect_location']);
			 }
		}
	}

}




function WP_sls_can_manage_options () {
	global $WP_sls_plugin_name;
	global $WP_sls_dbtable_version;
	global $WP_sls_options;		

	if (is_user_logged_in()){
		if(current_user_can('manage_options')) {
			/*
			 * let's auto-update the accesslog table
			 * if there's a new version
			 */
			WP_sls_update_db_check();
			/* 
			 * ok this is an administrator
			 * so don't redirect somewhere
			 * just let in.
			 */
			 include_once 'wpsls_admin.php';
		} else { 
			/*
			 * let WP redirect to 
			 */				
		}
	} else { 
		/*
		 * no direct access to wp-admin */
		WP_sls_redirectto($WP_sls_options['safe_redirect_location']);
	}
}


function WP_sls_security_code_field() {
	global $wpdb;	
	global $WP_sls_options;
	global $user;
	
	if ($WP_sls_options['enable_dual_authentication']=='yes'){
		if ( isset($user->error_data['attemptcode']) ){
			/* let's hide remember me checkbox if needed */		
			if ( $WP_sls_options['disable_remember_me']=='yes'){
				add_action('login_footer','WP_sls_remove_rememberme');
			}
			
			?>
				<p>
				<label for="WP_sls_security_code"><?php _e('Code','WP-simple-login-security') ?><br />
				<input type="password" name="WP_sls_security_code" id="WP_sls_security_code" class="input" value="" size="20" />
                <input type="hidden" name="WP_sls_security_try" id="WP_sls_security_try" class="input" value="<?php print $_POST['WP_sls_security_try']; ?>" readonly="readonly" />
				</label>
				</p>
	
				<p><?php _e('The code was sent to your email.','WP-simple-login-security') ?></p>
                
                <?php
				if ($WP_sls_options['show_powered_by']=='yes'){
					$wealthtrader_plugin_link = 'http://wealthtraders.com/wp-simple-login-security/';
					print '<p style="margin-bottom:10px;color:#777;font-size:0.8em;">'.__('Dual Authentication by','WP-simple-login-security').'<br /><a href="'.esc_url($wealthtrader_plugin_link).'">WP Simple Login Security</a></p>';
				}
                ?>
                
				<script type="text/javascript">
					document.getElementById('user_login').parentNode.style.display = 'none';
					document.getElementById('user_login').value = '<?php print $user->error_data['logstr']; ?>';
				</script>
			<?php	
			
		} else { 
			/* let's hide the remember me checkbox.  It's not needed here yet */
			add_action('login_footer','WP_sls_remove_rememberme');
			?>
            <input type="hidden" name="WP_sls_security_try" id="WP_sls_security_try" class="input" value="<?php print $_POST['WP_sls_security_try']; ?>" readonly="readonly" />
			<script type="text/javascript">
				document.getElementById('user_pass').parentNode.style.display = 'none';
				document.getElementById('user_pass').value = 'nopass';
			</script>
			<?php
		}
	} else { 
		/* let's hide remember me checkbox if needed */		
		if ( $WP_sls_options['disable_remember_me']=='yes'){
			add_action('login_footer','WP_sls_remove_rememberme');
		}	
		?>
        <input type="hidden" name="WP_sls_security_try" id="WP_sls_security_try" class="input" value="<?php print $_POST['WP_sls_security_try']; ?>" readonly="readonly" />
        <?php
	}
}




function WP_sls_validate_security_code($user, $password) {
	global $wpdb;
	
	if ( !isset($_POST['WP_sls_security_code'])){
		/*
		 * user is a valid username
		 * but not a valid password
		 * we just want to get the email address
		 */
		 if (isset($user->data->user_email)){
			 $WP_sls_login_user_email = $user->data->user_email;
			 $WP_sls_login_user_name = $user->data->user_login;

			 $user = new WP_Error('WP_sls_authentication_failed', __('Please enter password and the security code.','WP-simple-login-security'),'message');
			 $user->add_data($WP_sls_login_user_name,'logstr');
			 $user->add_data($WP_sls_login_user_email,'usreml');
			 $user->add_data('1','attemptcode'); // this indicates first login attempt
		 }
	} else { 
					
		if (isset($user->data->user_email)){
			 $WP_sls_login_user_email = $user->data->user_email;
			 $WP_sls_login_user_id = $user->data->ID;
			 $WP_sls_login_user_name = $user->data->user_login;
			 
			 /* let's check the security code first */
			$WP_sls_results = $wpdb->get_results("SELECT authcode FROM ".$wpdb->prefix."WP_sls_sessionlog WHERE userid='".$WP_sls_login_user_name."'");	
			
			 if ($_POST['WP_sls_security_code']==$WP_sls_results[0]->authcode){ 
				/*
				 * correct security code, pls proceed
				 * now let's check the password
				 */
			 } else { 
				 $user = new WP_Error('WP_sls_incorrect_code', '<strong>'.__('ERROR:','WP-simple-login-security').'</strong>'.__('The security code you entered is incorrect.','WP-simple-login-security'));
				 $user->add_data($WP_sls_login_user_name,'logstr');
				 $user->add_data($WP_sls_login_user_id,'usrid');
				 $user->add_data($WP_sls_login_user_email,'usreml');
				 $user->add_data('2','attemptcode'); // attemptcode 2 = meaning the user already entered correct username
			 }
		 } 	
	}
	return $user;
}





/*
 * function to hide the "remember me" checkbox
 */
function WP_sls_remove_rememberme(){ 
	echo '<script type="text/javascript">
				document.getElementById("rememberme").parentNode.style.display = "none";
			</script>';
}



function log_incorrect_code($user_login){ 
	global $WP_sls_options;
	global $wpdb;
	global $WP_sls_user_ip;
	
	if ($WP_sls_options['enable_logging']=='yes'){ 

		$WP_sls_error_message = '';
		if ($_POST['WP_sls_security_code']==''){
			$WP_sls_error_message = __('Empty code','WP-simple-login-security');
		} else { 
			$WP_sls_error_message = __('Incorrect code','WP-simple-login-security');
		}

		$wpdb->insert($wpdb->prefix."WP_sls_accesslog",
			array(
				'username'=>$user_login,
				'log_time'=>date('Y-m-d H:i:s'), 
				'authcode'=>$_POST['WP_sls_security_code'],
				'log_status'=>$WP_sls_error_message,
				'IP' => $WP_sls_user_ip
			),
			array( 
				'%s','%s','%s','%s','%s'
			)
		);
	}
}


function log_wrong_password($user_login){ 
	global $WP_sls_options;
	global $wpdb;
	global $WP_sls_user_ip;
	
	if ($WP_sls_options['enable_logging']=='yes' && isset($_POST['WP_sls_security_code']) ){ 

		$WP_sls_error_message = '';
		if ($_POST['pwd']==''){
			$WP_sls_error_message = __('Empty password','WP-simple-login-security');
		} else { 
			$WP_sls_error_message = __('Incorrect password','WP-simple-login-security');
		}
		
		if ($WP_sls_options['enable_dual_authentication']=='yes') {
			$authcode = $_POST['WP_sls_security_code'];
		} else { 
			$authcode = 'dual-factor authentication is disabled';
		}

		$wpdb->insert($wpdb->prefix."WP_sls_accesslog",
			array(
				'username'=>$user_login,
				'log_time'=>date('Y-m-d H:i:s'), 
				'authcode'=>$authcode,
				'log_status'=>$WP_sls_error_message,
				'IP' => $WP_sls_user_ip
			),
			array( 
				'%s','%s','%s','%s','%s'
			)
		);
	}
}




/*
 * we will finally update the accesslog before we logout 
 */
function WP_sls_logout() { 
	global $wpdb;
	global $WP_sls_user_ip;
	global $WP_sls_options;
	global $current_user;

	if ($WP_sls_options['enable_logging']=='yes'){
		
		if ($WP_sls_options['enable_dual_authentication']=='yes'){
		
			$WP_sls_results = $wpdb->get_results("SELECT authcode FROM ".$wpdb->prefix."WP_sls_sessionlog WHERE userid='".$current_user->user_login."'");	
					
			if ($wpdb->num_rows){
				
				$wpdb->insert($wpdb->prefix."WP_sls_accesslog",
					array(
						'username'=>$current_user->user_login,
						'log_time'=>date('Y-m-d H:i:s'),
						'authcode'=>$WP_sls_results[0]->authcode,
						'log_status'=>'logged out',
						'IP' => $WP_sls_user_ip
					),
					array( 
						'%s','%s','%s','%s','%s'
					)
				);
			} 
		} else { 
			/*
			 * let's update accesslog without authcode */
			$wpdb->insert($wpdb->prefix."WP_sls_accesslog",
				array(
					'username'=>$current_user->user_login,
					'log_time'=>date('Y-m-d H:i:s'),
					'authcode'=>__('dual-factor authentication is disabled','WP-simple-login-security'),
					'log_status'=>'logged out',
					'IP' => $WP_sls_user_ip
				),
				array( 
					'%s','%s','%s','%s','%s'
				)
			);
		}
	}
}



function WP_sls_login_footer(){
	global $errors;
	global $WP_sls_options;
	
	$query_connector = '&';
	if ($WP_sls_options['alt_wplogin_name']==''){
		$query_connector = '?';
	} 
	
	if ( stripos($_SERVER['REQUEST_URI'],'checkemail') ){
		echo '
			<script type="text/javascript">
				document.getElementById("loginform").remove();
			</script>
		';
	} elseif ( stripos($_SERVER['REQUEST_URI'],'lostpassword') ){
		echo '
			<script type="text/javascript">
				document.getElementById("lostpasswordform").action = "'.wp_login_url().$query_connector.'action=lostpassword";
				document.getElementById("lostpasswordform").elements["redirect_to"].value = "'.wp_login_url().$query_connector.'checkemail=confirm";
			</script>
		';
	} elseif ( stripos($_SERVER['REQUEST_URI'],'action=rp') ){ 
		echo '
			<script type="text/javascript">
				document.getElementById("resetpassform").action = "'.wp_login_url().$query_connector.'action=resetpass&key='.urlencode( $_GET['key'] ).'&login='.urlencode( $_GET['login'] ).'";
			</script>
		';
	} elseif ( stripos($_SERVER['REQUEST_URI'],'action=register') ){ 
		echo '
			<script type="text/javascript">
				document.getElementById("registerform").action = "'.wp_login_url().$query_connector.'action=register";
				document.getElementById("registerform").elements["redirect_to"].value = "'.wp_login_url().$query_connector.'checkemail=registered";
			</script>
		';
	} else {
		echo '
			<script type="text/javascript">
				document.getElementById("loginform").action = "'.wp_login_url().'";
			</script>
		';
	}
}


function WP_sls_logout_url( $logout_url, $redirect ) {
	global $WP_sls_options;
	if ($WP_sls_options['alt_wplogin_name']==''){
		if ($redirect==''){
			$new_logout_url = $logout_url;
		} else {
			$new_logout_url = $logout_url.'&amp;redirect_to='.$redirect;
		}
	} else {
		if ($redirect==''){
			$new_logout_url = $logout_url.'&amp;redirect_to='.urlencode(home_url().'/wp-login.php?'.$WP_sls_options['alt_wplogin_name'].'&loggedout=true');
		} else {
			$new_logout_url = $logout_url.'&amp;redirect_to='.$redirect;
		}
	}
    return $new_logout_url;
}

function WP_sls_login_url( $login_url, $redirect ) {
	global $WP_sls_options;
	if ($WP_sls_options['alt_wplogin_name']==''){
		if ($redirect==''){
			$new_login_url = $login_url;
		} else {
			$new_login_url = $login_url.'&amp;redirect_to=' . $redirect;
		}
	} else {
		if ($redirect==''){
			$new_login_url = $login_url.'?'.$WP_sls_options['alt_wplogin_name'];
		} else {
			$new_login_url = $login_url.'?'.$WP_sls_options['alt_wplogin_name'].'&amp;redirect_to=' . $redirect;
		}
	}
    return $new_login_url;
}




?>